@@ -1,7 +1,8 @@
 """Asynchronous Python client for Sonarr."""
-from .sonarr import (  # noqa
-    Sonarr,
+from .exceptions import (  # noqa
     SonarrAccessRestricted,
     SonarrConnectionError,
     SonarrError,
+    SonarrResourceNotFound,
 )
+from .sonarr import Client, Sonarr  # noqa
